@@ -3,11 +3,10 @@ Data represents measurement data for this device.
 
 It contains wifi strength and energy/gas data
 """
+from __future__ import annotations
 
 from datetime import datetime
-from .helpers import generate_attribute_string
-from .errors import RequestError
-
+from typing import Coroutine
 
 available_attributes = [
     "available_datapoints",
@@ -31,16 +30,12 @@ available_attributes = [
 class Data:
     """Represent Device config."""
 
-    def __init__(self, request):
+    def __init__(self, request: Coroutine) -> None:
         """Initialize new Data object."""
         self._raw = None
         self._request = request
         self.available_datapoints = []
 
-    def __str__(self):
-        """Return readable string describint this object."""
-        return generate_attribute_string(self, available_attributes)
-
     def __eq__(self, other: object) -> bool:
         """Return true when other object is equal to this object."""
         if other is None:
@@ -48,7 +43,7 @@ class Data:
         return self._raw == other._raw
 
     @property
-    def smr_version(self):
+    def smr_version(self) -> int | None:
         """
         SMR version of P1 meter.
 
@@ -57,7 +52,7 @@ class Data:
         return self._raw["smr_version"] if "smr_version" in self._raw else None
 
     @property
-    def meter_model(self):
+    def meter_model(self) -> str | None:
         """
         SMR version of P1 meter.
 
@@ -66,7 +61,7 @@ class Data:
         return self._raw["meter_model"] if "meter_model" in self._raw else None
 
     @property
-    def wifi_ssid(self):
+    def wifi_ssid(self) -> str | None:
         """
         Wi-fi SSID currently in use (string).
 
@@ -75,7 +70,7 @@ class Data:
         return self._raw["wifi_ssid"] if "wifi_ssid" in self._raw else None
 
     @property
-    def wifi_strength(self):
+    def wifi_strength(self) -> int | None:
         """
         Wifi strength in percentage (number, 0-100), where 100 is best.
 
@@ -84,7 +79,7 @@ class Data:
         return self._raw["wifi_strength"] if "wifi_strength" in self._raw else None
 
     @property
-    def total_power_import_t1_kwh(self):
+    def total_power_import_t1_kwh(self) -> float | None:
         """
         Total power import value for counter 1 (number).
 
@@ -97,7 +92,7 @@ class Data:
         )
 
     @property
-    def total_power_import_t2_kwh(self):
+    def total_power_import_t2_kwh(self) -> float | None:
         """
         Total power import value for counter 2 (number).
 
@@ -110,7 +105,7 @@ class Data:
         )
 
     @property
-    def total_power_export_t1_kwh(self):
+    def total_power_export_t1_kwh(self) -> float | None:
         """
         Total power export value for counter 1 (number).
 
@@ -123,7 +118,7 @@ class Data:
         )
 
     @property
-    def total_power_export_t2_kwh(self):
+    def total_power_export_t2_kwh(self) -> float | None:
         """
         Total power export value for counter 2 (number).
 
@@ -136,7 +131,7 @@ class Data:
         )
 
     @property
-    def active_power_w(self):
+    def active_power_w(self) -> float | None:
         """
         Active consumption in watts (number).
 
@@ -145,7 +140,7 @@ class Data:
         return self._raw["active_power_w"] if "active_power_w" in self._raw else None
 
     @property
-    def active_power_l1_w(self):
+    def active_power_l1_w(self) -> float | None:
         """
         Active consumption in watts for line 1 (number).
 
@@ -156,7 +151,7 @@ class Data:
         )
 
     @property
-    def active_power_l2_w(self):
+    def active_power_l2_w(self) -> float | None:
         """
         Active consumption in watts for line 2 (number).
 
@@ -169,7 +164,7 @@ class Data:
         )
 
     @property
-    def active_power_l3_w(self):
+    def active_power_l3_w(self) -> float | None:
         """
         Active consumption in watts for line 3 (number).
 
@@ -182,7 +177,7 @@ class Data:
         )
 
     @property
-    def total_gas_m3(self):
+    def total_gas_m3(self) -> float | None:
         """
         Total gas usage in m3 (number).
 
@@ -192,7 +187,7 @@ class Data:
         return self._raw["total_gas_m3"] if "total_gas_m3" in self._raw else None
 
     @property
-    def gas_timestamp(self):
+    def gas_timestamp(self) -> str | None:
         """
         Latest gas timestamp (number).
 
@@ -209,12 +204,12 @@ class Data:
         date = datetime.strptime(str(self._raw["gas_timestamp"]), "%y%m%d%H%M%S")
         return date.isoformat()
 
-    async def update(self):
+    async def update(self) -> bool:
         """Fetch new data for object."""
-        status, response = await self._request("get", "api/v1/data")
+        response = await self._request("get", "api/v1/data")
 
-        if status != 200 or not response:
-            raise RequestError
+        if response is None:
+            return False
 
         self._raw = response
 
