@@ -1,7 +1,9 @@
 """State represents state of device, eg. as 'power_on'."""
+from __future__ import annotations
 
 import logging
-from .helpers import generate_attribute_string
+from typing import Coroutine
+from .errors import RequestError
 
 _LOGGER = logging.getLogger(__name__)
 
@@ -9,50 +11,47 @@ _LOGGER = logging.getLogger(__name__)
 class State:
     """Represent current state."""
 
-    def __init__(self, request):
+    def __init__(self, request: Coroutine):
         """Initialize new State object."""
         self._raw = None
         self._request = request
 
-    def __str__(self):
-        """Return readable string describint this object."""
-        attributes = ["power_on", "switch_lock", "brightness"]
-        return generate_attribute_string(self, attributes)
-
     def __eq__(self, other: object) -> bool:
         """Return true when other object is equal to this object."""
         if other is None:
             return False
         return self._raw == other._raw
 
-    async def set(self, power_on=None, switch_lock=None, brightness=None):
+    async def set(
+        self,
+        power_on: bool | None = None,
+        switch_lock: bool | None = None,
+        brightness: int | None = None,
+    ) -> bool:
         """Set state of device."""
         state = {}
-        if isinstance(power_on, bool):
+
+        if power_on is not None:
             state["power_on"] = power_on
-        if isinstance(switch_lock, bool):
+        if switch_lock is not None:
             state["switch_lock"] = switch_lock
-        if isinstance(brightness, int):
+        if brightness is not None:
             state["brightness"] = brightness
 
         if state == {}:
             _LOGGER.error("At least one state update is required")
-            return False, ""
+            return False
 
-        status, response = await self._request("put", "api/v1/state", state)
-        if status == 200 and response:
-            # Zip result and original
-            self._raw = {**self._raw, **response}
-            return True, response
-
-        error_message = ""
         try:
-            error_message = response["error"]["description"]
-        except (NameError, AttributeError, ValueError):
-            error_message = response
+            response = await self._request("put", "api/v1/state", state)
+            if response is not None:
+                # Zip result and original
+                self._raw = {**self._raw, **response}
+                return True
 
-        _LOGGER.error("Failed to set state: %s", error_message)
-        return False, response
+        except RequestError:
+            _LOGGER.error("Failed to set state")
+            return False
 
     @property
     def power_on(self) -> bool:
@@ -80,9 +79,9 @@ class State:
 
     async def update(self) -> bool:
         """Fetch new data for object."""
-        status, response = await self._request("get", "api/v1/state")
-        if status == 200 and response:
-            self._raw = response
-            return True
+        response = await self._request("get", "api/v1/state")
+        if response is None:
+            return False
 
-        return False
+        self._raw = response
+        return True
